Package: EDIutils
Title: An API Client for the Environmental Data Initiative Repository
Version: 3.0.0
Authors@R: 
    c(person("Colin", "Smith", email = "colin.smith@wisc.edu", role = c("aut", "cre"), comment = "0000-0003-2261-9931"),
    person("Corinna", "Gries", role = "ctb", comment = "0000-0002-9091-6543"),
    person("Jasmine", "Lai", role = "rev", comment = "0000-0001-8888-547X"),
    person("Rodrigo", "Pires", role = "rev", comment = "0000-0001-7384-6849"))
Description: A client for the Environmental Data Initiative repository REST API. The 'EDI' data repository <https://portal.edirepository.org/nis/home.jsp> is for publication and reuse of ecological data with emphasis on metadata accuracy and completeness. It is built upon the 'PASTA+' software stack <https://pastaplus-core.readthedocs.io/en/latest/index.html#> and was developed in collaboration with the US 'LTER' Network <https://lternet.edu/>. 'EDIutils' includes functions to search and access existing data, evaluate and upload new data, and assist other data management tasks common to repository users.
Imports: curl, httr, jsonlite, xml2, utils
License: MIT + file LICENSE
Encoding: UTF-8
Suggests: knitr, readr, vcr, rmarkdown, roxygen2, testthat
URL: https://github.com/ropensci/EDIutils,
        https://docs.ropensci.org/EDIutils/
BugReports: https://github.com/ropensci/EDIutils/issues
VignetteBuilder: knitr
Language: en-US
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-27 21:53:21 UTC; csmith
Author: Colin Smith [aut, cre] (0000-0003-2261-9931),
  Corinna Gries [ctb] (0000-0002-9091-6543),
  Jasmine Lai [rev] (0000-0001-8888-547X),
  Rodrigo Pires [rev] (0000-0001-7384-6849)
Maintainer: Colin Smith <colin.smith@wisc.edu>
Repository: CRAN
Date/Publication: 2026-07-27 22:10:01 UTC
Built: R 4.6.1; ; 2026-07-27 23:53:54 UTC; unix
