context("List data entities")

# testthat::test_that("list_data_entities() works", {
#   pkg <- "edi.993.1"
#   vcr::use_cassette("list_data_entities", {
#     res <- list_data_entities(pkg)
#   })
#   expect_equal(class(res), "character")
#   expect_true(length(res) > 0)
# })
